Bond

Struct Bond 

pub struct Bond {
    pub atom1: usize,
    pub atom2: usize,
}
Structure representing a bond between atoms.

Fields

atom1: usize

Global index of the first atom involved in the bond. Note the word is index, not number! Atom indices start from 0. Indices correspond to indices of the atoms in the TprTopology::atoms vector.

atom2: usize

Global index of the second atom involved in the bond.