pub struct Bond {
pub atom1: usize,
pub atom2: usize,
}Expand description
Structure representing a bond between atoms.
Fields
atom1: usizeGlobal index of the first atom involved in the bond.
Note the word is index, not number! Atom indices start from 0.
Indices correspond to indices of the atoms in the TprTopology::atoms vector.
atom2: usizeGlobal index of the second atom involved in the bond.